package com.ibm.rational.cdi;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;

public class UpdateWASProperties {

	private boolean changed=false;
	
	public void run(String[] args, PrintWriter writer){
		if (args.length!=2){
			reportError(writer, "Invalid number of arguments: "+args.length);
			return;
		}
		
		String propFileName=args[0];
		String installDir=args[1];
		
		File propFile=new File(propFileName);
		if (!propFile.exists()){
			reportError(writer, "Properties File not found: "+propFile);
			return;
		}
		
		File newFile=new File(propFileName+".new");
		File backupFile=new File(propFileName+".bak");
		
		
		try {
			BufferedReader file_reader;
			PrintWriter file_writer;
			
			file_reader=new BufferedReader(new FileReader(propFile));
			file_writer=new PrintWriter(new FileWriter(newFile));
			
			for (;;){
				String line=file_reader.readLine();
				if (line==null){
					break;
				}
				
				String newLine=processLine(line, installDir);
				
				file_writer.println(newLine);
				
			}
			
			file_reader.close();
			file_writer.close();
			
		} catch (FileNotFoundException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		} 		
		
		if (changed) {
			File origFile=propFile;
			propFile.renameTo(backupFile);
			newFile.renameTo(origFile);
		}
	}

	private String processLine(String oldLine, String installDir){
		String newLine;
		if (oldLine.startsWith("user.root=runtimes/base_v61_stub")){
			newLine="user.root="+installDir+"/runtimes/base_v61_stub";
		}
		else {
			return oldLine;
		}
		
		changed=true;
		return newLine;
	}
	
	private void reportError(PrintWriter writer, String msg){
		writer.println("UpdateWASProperties: "+msg);
	}

	
	public static void main(String[] args) {
		UpdateWASProperties obj=new UpdateWASProperties();
		obj.run(args, new PrintWriter(System.out));

	}

}
